#
# spec file for package linphone
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 3.8
Name:           linphone
Version:        3.8.0
Release:        92.1
Summary:        Web Phone
License:        GPL-2.0+
Group:          Productivity/Networking/Other
Url:            https://linphone.org
Source0:        http://download.savannah.gnu.org/releases/linphone/%{_version}.x/sources/%{name}-%{version}.tar.gz
Source1:        %{name}-manual.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libeXosip2-devel
BuildRequires:  libgsm-devel
BuildRequires:  libtool
BuildRequires:  readline-devel
BuildRequires:  sgmltool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(belle-sip) >= 1.3.1
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.18.0
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libosip2)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(libv4l2) >= 0.8.4
BuildRequires:  pkgconfig(libzrtpcpp) >= 4.0
BuildRequires:  pkgconfig(mediastreamer) >= 2.10.0
BuildRequires:  pkgconfig(ortp) >= 0.23.0
BuildRequires:  pkgconfig(speex) >= 1.1.6
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(udev)
Recommends:     %{name}-lang = %{version}
# Video support - disabled by default due to patent issues.
%if 0%{?packman_bs}
BuildRequires:  libffmpeg-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(xv)
%endif

%description
Linphone is a Web phone with a GNOME interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%package devel
Summary:        Web Phone
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       glibc-devel
Requires:       libeXosip2-devel
Requires:       libosip2-devel
Requires:       pkgconfig(alsa)
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(speex)
%if 0%{?packman_bs}
Requires:       libffmpeg-devel
Requires:       pkgconfig(xv)
%endif

%description devel
Linphone is a Web phone with a GNOME interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%lang_package

%prep
%setup -q
%setup -q -D -T -a 1
# Set tutorial path inside linphone in /usr/share.
sed -i "s|\(\$(datadir)/\)\(tutorials\)/%{name}|\1%{name}/\2|" coreapi/help/Makefile.{in,am}

%build
# autoreconf -fi does not work properly.
./autogen.sh
%configure \
  --docdir=%{_docdir}             \
  --enable-pulseaudio             \
  --enable-external-ortp          \
  --enable-external-mediastreamer \
  --enable-zrtp                   \
%if !0%{?packman_bs}
  --disable-video                 \
%endif
  --disable-strict                \
  --disable-static

make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file -r -D "%{name}/index.xml.html" %{name} Network Telephony
find %{buildroot} -type f -name "*.la" -delete -print
# Remove duplicate COPYING.
rm -f %{buildroot}%{_datadir}/%{name}/COPYING
# Install the manual.
mkdir -p %{buildroot}%{_datadir}/gnome/help/
cp -a %{name} %{buildroot}%{_datadir}/gnome/help/%{name}/
%find_lang %{name}
%fdupes %{buildroot}

%post
%desktop_database_post
/sbin/ldconfig

%postun
%desktop_database_postun
/sbin/ldconfig

%files
%defattr(-,root,root)
%doc NEWS AUTHORS COPYING
%{_bindir}/*
%{_libdir}/lib%{name}.so.*
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/tutorials/
%{_datadir}/sounds/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}/
%{_mandir}/man?/*.?%{?ext_man}
%{_mandir}/*/man?/*.?%{?ext_man}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/tutorials/

%files lang -f %{name}.lang
%defattr(-,root,root)
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/

%changelog
* Sat Mar 28 2015 sor.alexei@meowr.ru
- Regenerate configure with autotools to solve build problems in
  some cases.
- Remove redefinition of GenericName in desktopfile.
* Sun Mar 15 2015 sor.alexei@meowr.ru
- Update to 3.8.0:
  + Application level improvements:
  * The video window has now controls in order to switch
    fullscreen mode and terminate call.
  * The out of call video preview feature (to test camera) is
    moved into the settings and is no longer linked to the in-call
    video preview feature.
  * Add an assistant to help users to set audio/video parameters.
  * Some ergonomics improvments (checkbox to set random port for
    UDP and TCP, ...).
  * Lots of updated translations. Arabic translation has been
    added.
  * Experimental feature: play an MKV file by drag-and-dropping
    it on the video call window.
  + Liblinphone level improvements:
  * Support for RTP/AVPF (RFC4585) for video streams, allowing fast
    transmission error recovery with VP8 codec only.
  * API enhancements, most objects can be ref-counted.
  * Add some getter funtctions to the call information API.
  * Add a function in the API to accept early-media calls.
  * Add a function to set the SIP transport timeout.
  * Add a function to change adaptive rate algorithm at runtime.
  * Add support of file transfer.
  * Call video recording feature, in mkv format (H264 streams only
    for the moment).
  * Call playing feature: play an MKV file and send the audio/video
    stream through a call.
  * Local player API. Play WAV and MKV file and display video on a
    specified window display.
  * A wrapper for Python has been made.
  * Support of multicast IP addresses.
  * Support of incoming UPDATEs within dialog (RFC3311).
  * Support of SRTP by using packages from distributions.
- Spec cleanup.
* Fri Aug 15 2014 fisiu@opensuse.org
- Update to 3.7.0:
  Application level improvements:
  * It is now possible to configure multiple proxy accounts with different
    transports (UDP, TCP, TLS)
  * can work with IPv6 and IPv4 simultaneously
  * User can choose video rendering method on Linux
  * Video HD formats support added, leveraging on multiple cores for encoding
    if available
  * Keyboard can be used for DTMF input
  * Faster and higly responsive UI thanks to fully asynchronous operation of
    the liblinphone.
  * Addon of opus codec
  * Possibility to specify a remote provisionning http URI for configuration
  * LDAP search integration for Linux and MacOSX
  * is-composing notification in chat area
  Liblinphone level improvements thanks to new "belle-sip" SIP stack:
  * multiple SIP transports simultaneously now allowed
  * IP dual stack: can use IPv6 and IPv4 simultaneously
  * fully asynchronous behavior: no more lengthly DNS or connections
  * +sip.instance parameter (RFC5626)
  * alias parameter (RFC5923)
  * better management of network disconnections
  * SIP/TLS handled through lightweighted polarssl library (instead of
    openssl)
  * SIP transaction state machines improved (RFC6026)
  * Privacy API (RFC3323, RFC3325)
  * Full support of rich presence in (RFC4480)
  * Better handling of sips scheme in URIs.
  * Messaging: support of is-composing (RFC3994)
  * Call transfer fixes in error cases
  * Add API for managing SIP SUBSCRIBES/NOTIFY/PUBLISH (linphonecore/event.h)
  * bugfixes
* Tue Feb 11 2014 zaitor@opensuse.org
- Version pkgconfig(libzrtpcpp) BuildRequires to resolve build for
  13.2 and newer.
* Thu Jun 20 2013 fisiu@opensuse.org
- Update to 3.6.1:
  * UI:
  * new friend list and chat messaging UI
  * enhanced call history
  * call and conference audio recording
  * persistent chat history
  * DSCP settings for SIP and RTP
  * display of call statistics (when clicking on the quality indicator bar)
  * Core:
  * ICE for efficient RTP exchange
  * fix bug in zRTP support (upgrade required)
  * call recording
  * uPnP
  * call statistics
  * adaptive bitrate control improvements
  * faster call quality indicator feedback
  * DSCP settings for SIP and RTP
  * detailed call statistics feedback API
- Drop linphone-ffmpeg.patch and linphone-v4l.patch: they were for
  shipped mediastreamer but we're using external one.
- Spec cleanup.
* Sat Mar  2 2013 seife+obs@b1-systems.com
- fix build with automake-1.13.1
* Mon Nov 12 2012 mailaender@opensuse.org
- add libsrtp and libzrtpcpp as build dependency
* Sat Oct 27 2012 mailaender@opensuse.org
- use external libortp and mediastreamer2
* Fri Oct 12 2012 vadimuzzz@inbox.ru
- added video support (disabled by default), to enable need to rebuild "with video"
- modify patch linphone-v4l (ffmpeg API changed)
- added linphone-ffmpeg.patch (ffmpeg API changed)
* Mon May 21 2012 jengelh@inai.de
- Use BuildRequires: pkgconfig(gnutls) instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Tue May 15 2012 i@marguerite.su
- update to version 3.5.2
  * updated oRTP to 0.20.0
  * updated mediastreamer2 to 2.8.2
  * added ZRTP media encryption
  * added SILK audio codec
- modify patch linphone-v4l.
- drop applet sub-package. since no useful data.
* Thu Nov 24 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Thu Nov 24 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Jul 24 2011 seife+obs@b1-systems.com
- update to version 3.4.3, see NEWS file for detailed changelog,
  obsoletes patches
- build / packaging improvements:
  - remove build date from binaries, use the tarball's timestamp
  - verbose build for rpmlint checking
  - add AUTHORS, NEWS, COPYING files
  - fix rpm group of devel package
  - add alsa-devel and libgsm-devel buildrequires
  - explicitly enable alsa, ssl, rsvp, ipv6
* Tue Jul 12 2011 cwh@novell.com
- fixing 11.4 build
* Thu Jul  7 2011 idonmez@novell.com
- Add linphone-v4l-2.6.38.patch: use new v4l interface
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Jan 16 2011 seife+obs@b1-systems.com
- Patch up to current git state of branch 3.3.x. Unfortunately,
  the git history is not helpful to create a changelog.
  But this fixes bnc#664808.
* Wed Dec 29 2010 aj@suse.de
- Run spec file through spec-cleaner.
- Remove build dependencies on libgnomeprintui-devel and
  libwnck-devel, they are not needed.
* Thu Nov 11 2010 coolo@novell.com
- own parent directory for gnome-panel
* Wed Aug 11 2010 ro@suse.de
- update to linphone-3.3.2
  * enhancements made to presence support (SIP/SIMPLE)
  * be nat friendly using OPTIONS request and using received,rport from
  responses.
  * use stun guessed ports even if symmetric is detected (works with freeboxes)
  * improve bitrate usage of speex codec
  * allow speex to run with vbr (variable bit rate) mode
  * add speex/32000 (ultra wide band speex codec)
  * answer empty SIP INFO requests
  * reverse order of call logs
  * optimize video display
  * manual or automatic network connectivity management (so that REGISTERs
  are only sent when network is up or refreshed when it comes back)
  * new in-call layout
  * new idle view with two buttons
  * ability to dial the number from dialpad
  * improve local IP address detection when having multiple networks (ex: VPNs)
  * use proxy's received and rport params from via in Contact header when possible
  * add an option to ask linphone to place a call, whenever an instance is already running or not:
  should be useful for starting calls from a web browser recognizing the 'sip:' uri scheme.
  * don't show ffmpeg codecs when encoder are disabled in ffmpeg library.
  * update theora default settings to match performance of 1.0 release.
  * linphone can now send large video pictures: up to SVGA, configurable via the user interface
  * automatic rescaling of the video windows to the video size of incoming stream
  * enable lookups of SRV records
  * new 'linphonecsh' program to send commands to a linphonec running as daemon using unix sockets or tcp.
  - tons of bugfixes, please see NEWS file for details
- update to version 3.0.0
  * new graphical interface based on Glade/Gtk
  * systray icon
  * STUN working for RTP
  * accurate bandwidth management (to let video occupy all remaning bandwidth)
  * new H264 plugin based on x264 (msx264)
  * automatic call hangup upon media transmission faillure
* Wed Dec  2 2009 coolo@novell.com
- update patch to fix build
* Mon May 25 2009 hvogel@suse.de
- Translations update
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translations update.
* Wed Oct 22 2008 hvogel@suse.de
- get rid of autoreconf call to make it build again
* Fri Apr 18 2008 hvogel@suse.de
- Hide online help button, we dont have an XML file to pass to
  gnome_help_display so its of no use.
* Thu Apr  3 2008 hvogel@suse.de
- update to version 2.1.1
  * Clean up commands 'nat', 'stun' and 'firewall' to be
    more intuitive
  * Upgrade to newest gettext
- fix some rpmlint warnings
- get rid of libtool archives
* Fri Jan 18 2008 mskibbe@suse.de
- portate to new libosip version
- fix typo in linphone-1.3.0.patch
* Wed Jan 16 2008 mskibbe@suse.de
- update to version 2.0.1 which
  o use new (eX)osip version
  o Clean ANSI/C vs. ANSI/C++ differences
  o fix a lot of small bugs
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Sep  4 2007 mskibbe@suse.de
- update to versin 1.7.1:
  * arts sound input/output
  * improved sound latency with alsa
  * alsa support works with dmix/dsnoop
  * fix a lot of bugs
* Tue Jun 19 2007 mskibbe@suse.de
- disable Werror
* Wed May 16 2007 ro@suse.de
- use libosip2-devel in buildrequires
* Thu Mar  8 2007 mskibbe@suse.de
- add missing directories
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Feb  8 2007 mskibbe@suse.de
- fix build problems
* Tue Jan 16 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Aug 10 2006 mskibbe@suse.de
- update to version 1.3.0 which includes
  o a lots of improvements in linphonec (see strk 's Changelogs below)
  o telephone event problem with sipomatic.
  o updated cz translation.
  o fix bugs around addressbook.
  o video support with H263-1998/RFC2429 nearly clean.
  o added timeout for incoming calls
* Sat Feb 18 2006 gekker@suse.de
- Update .desktop file for UI team
* Wed Feb 15 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 hvogel@suse.de
- Update to version 1.2.0
* Fri Nov 11 2005 hvogel@suse.de
- care about return values. Added
  * linphone-returnchecks.patch
* Wed Oct  5 2005 hvogel@suse.de
- update to version 1.1.0 drop
  * linphone-manual.patch
  * linphone-cs_cz.patch
  * linphone-cs_cz-fixes.patch
  * linphone-configure.patch
* Fri Sep  9 2005 hvogel@suse.de
- update cz translation
* Fri Jul  8 2005 mmj@suse.de
- fix more prototypes
* Tue Jul  5 2005 mmj@suse.de
- fix unitialized vars
- fix prototypes
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Wed Apr 20 2005 hvogel@suse.de
- fix bonobo server file to include an icon
- fix desktop file to have both Name and GenericName
- fix return values
* Tue Mar 22 2005 max@suse.de
- Update to final 1.0.0 version, which is more stable (#74253).
* Tue Mar 22 2005 sbrabec@suse.cz
- Moved applet bonobo server description to linphone-applet.
* Tue Mar 22 2005 coolo@suse.de
- split the gnome applet into an own package (#74199)
* Thu Mar 17 2005 hvogel@suse.de
- fix desktop file
* Tue Feb 15 2005 ro@suse.de
- added czech translations by Klara Cihlarova
* Thu Feb  3 2005 hvogel@suse.de
- add the manual so the manual button works
* Mon Jan 24 2005 ro@suse.de
- mark as NoSource (ffmpeg is there but unused).
* Wed Jan 19 2005 ro@suse.de
- update to 1.0.0pre6
- fixed more compiler warnings
* Sun Nov 14 2004 ro@suse.de
- fix another compile warning
* Tue Nov  9 2004 ro@suse.de
- update to 1.0.0pre4
- split patch in pieces
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed applet broken by bad libdir usage.
- Fixed libexecdir for bi-arch (#47050).
* Wed Jul 28 2004 ro@suse.de
- update to 1.0.0pre1
* Wed May 19 2004 ro@suse.de
- update to 0.12.2
- fix some compiler warnings
* Tue Feb  3 2004 ro@suse.de
- use -fno-strict-aliasing
* Wed Jan 21 2004 ro@suse.de
- update to 0.12.1
- make it build
* Mon Oct 20 2003 ro@suse.de
- don't build as root
* Sat Aug 23 2003 ro@suse.de
- update to 0.12.0
* Tue Jul 29 2003 ro@suse.de
- install it all to /opt/gnome
* Thu Jul 17 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
- Added gnome-panel to neededforbuild.
* Wed Jun 11 2003 ro@suse.de
- fix desktop file path
* Wed Jun 11 2003 ro@suse.de
- libtoolize in osipua subdirectory for proper soname
* Tue Jun 10 2003 ro@suse.de
- created package (version 0.11.0)
- use system speex library
